@@ -137,7 +137,8 @@ print.Future <- function(x, ...) {
     g <- head(g, n = 5L)
     gSizes <- head(gSizes, n = 5L)
     g <- sprintf("%s %s of %s", sapply(g, FUN = function(x) class(x)[1]), sQuote(names(g)), sapply(gSizes, FUN = asIEC))
-    if (ng > 5L) g <- sprintf("%s ...", g)
+    if (ng > length(g)) g <- c(g, "...")
+    g <- hpaste(g, maxHead = 5L, maxTail = 0L)
     cat(sprintf("Globals: %d objects totaling %s (%s)\n", ng, asIEC(gTotalSize), g))
   } else {
     cat("Globals: <none>\n")
