@@ -22,6 +22,33 @@ print(calls)
 message("*** backtrace( ) - implicit future ... DONE")
 
 
+message("*** backtrace( ) - subsetting ...")
+
+env <- new.env()
+env[["a"]] %<-% { 42L; stop("Woops") }
+env[["b"]] %<-% { 42L; stop("Woops") }
+calls <- backtrace(env[["b"]])
+print(calls)
+stopifnot(is.list(calls))
+
+lenv <- listenv::listenv()
+lenv[[1]] %<-% { 42L; stop("Woops") }
+lenv[[2]] %<-% { 42L; stop("Woops") }
+calls <- backtrace(lenv[[2]])
+print(calls)
+stopifnot(is.list(calls))
+
+ll <- list()
+ll[[1]] <- future({ 42L; stop("Woops") })
+ll[[2]] <- future({ 42L; stop("Woops") })
+vs <- values(ll, signal = FALSE)
+calls <- backtrace(ll[[2]])
+print(calls)
+stopifnot(is.list(calls))
+
+message("*** backtrace( ) - subsetting ... DONE")
+
+
 message("*** backtrace( ) - exceptions ...")
 
 message("- No condition ...")
