@@ -62,6 +62,39 @@ for (size in c(0, 10 ^ (0:20))) {
 message("*** asIEC() ... DONE")
 
 
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# .length()
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+message("*** .length() ...")
+.length <- future:::.length
+
+objs <- list(
+  a = 1:3,
+  b = as.list(1:3),
+  c = structure(as.list(1:3), class = c("foo", "list")),
+  d = data.frame(a = 1:3),
+  e = as.environment(list(a = 1:3))
+)
+truth <- c(a = 3L, b = 3L, c = 3L, d = 1L, e = 1L)
+
+## Special case: length(x) == 5, but .length(x) == 2
+## BUG FIX: https://github.com/HenrikBengtsson/future/issues/164
+if (requireNamespace("tools")) {
+  objs[["f"]] <- structure(list("foo", length = 5L), class = "pdf_doc")
+  truth["f"] <- 2L
+}
+
+for (name in names(objs)) {
+  obj <- objs[[name]]
+  len <- length(obj)
+  .len <- .length(obj)
+  cat(sprintf("%s: length = %d, .length = %d, expected = %d\n",
+              name, len, .len, truth[name]))
+  stopifnot(.len == truth[name])
+}
+
+message("*** .length() ... DONE")
+
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # debug()
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
